@@ -197,7 +197,8 @@ class Builder(Update):
 
     def apply_templates(self, target=None, useClt=None, cltFilter=False,
                         root=None,
-                        useDispatch=True, action="merge", distro_dv=None):
+                        useDispatch=True, action="merge", distro_dv=None,
+                        themes=False):
         """
         Применить шаблоны.
 
@@ -261,6 +262,13 @@ class Builder(Update):
             nullProgress = lambda *args, **kw: None
             dispatch = self.dispatchConf if useDispatch else None
 
+            if themes:
+                for k, v in {'cl_action': 'merge',
+                             'cl_merge_pkg': [None],
+                             'cl_merge_set': "on",
+                             'install.cl_setup': 'themes'}.items():
+                    clVars.Set(k, v, force=True)
+
             clTempl = ProgressTemplate(nullProgress, clVars,
                                        cltObj=useClt,
                                        cltFilter=cltFilter,
@@ -1573,3 +1581,22 @@ class Builder(Update):
             self.pkgnum = None
 
         return True
+
+    def update_dracut(self, builder_path):
+        """
+        Обновить initramfs
+        :param builder_path:
+        :return:
+        """
+        cmd = "/usr/bin/dracut"
+        cmd_path = self.get_prog_path(cmd)
+        logfile = self._get_log_file()
+        if not cmd_path:
+            raise BuilderError(_("Failed to find the %s command") % cmd)
+        kver = self.clVars.Get("builder.cl_builder_kernel_ver")
+        dracut = self.chrootize(
+            builder_path,
+            CommandExecutor(cmd_path, ["--xz", "-f", "--kver", kver],
+                            logfile=logfile))
+        dracut.execute()
+        return dracut.success()
