@@ -1700,3 +1700,16 @@ class VariableClBuilderCheckAutomagicSet(Variable):
         self.label = _("Check for auto depends")
         self.help = _("check for auto depends")
 
+
+class VariableClBuilderUpdateThemesSet(Variable):
+    """
+    Перенастроить темы перед запаковкой
+    """
+    type = "bool"
+    value = "off"
+
+    opt = ["--update-themes", "-U"]
+
+    def init(self):
+        self.label = _("Update themes")
+        self.help = _("update themes")
